@@ -27,7 +27,9 @@
 #include "File_manager.hpp"
 #include "error/Build_error.hpp"
 #include "error/Posix_error.hpp"
+#include <string>
 
+using std::string;
 using Roan_trail::Long_int;
 using namespace Roan_trail::Builder;
 
@@ -185,7 +187,7 @@ bool Movie::setup(Sound_source* sound_source, Error_param& return_error)
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error())
+  postcondition(return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -219,7 +221,7 @@ bool Movie::start(const string& movie_path,
   const bool sound_started = m_sound_track->start(error);
   on_error(!sound_started, new Build_error(error_location(),
                                            Build_error::general,
-                                   error()));
+                                           error()));
   need_sound_end = true;
 
   // create a temporary movie file
@@ -314,7 +316,7 @@ bool Movie::start(const string& movie_path,
                         && (("" == temporary_file_path)
                             || !File_manager::path_exists(temporary_file_path))
                         && !m_started))
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -366,13 +368,15 @@ bool Movie::add(const uint8_t* raw_video_frame,
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
   postcondition(m_setup
                 && m_started
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -421,13 +425,15 @@ bool Movie::add_silent(const uint8_t* raw_video_frame,
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
   postcondition(m_setup
                 && m_started
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -507,7 +513,7 @@ bool Movie::end(Error_param& return_error)
  exit_point:
   postcondition(m_setup
                 && !m_started
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
