@@ -49,15 +49,20 @@
 #include "error/Build_error.hpp"
 #include "error/Posix_error.hpp"
 #include <iomanip>
+#include <string>
 #include <sstream>
+#include <vector>
 #include <cmath>
 #include <sys/stat.h>
 
-using std::stringstream;
 using std::endl;
 using std::setw;
 using std::setfill;
+using std::string;
+using std::stringstream;
+using std::vector;
 using Roan_trail::Recorder::Segment;
+using Roan_trail::Recorder::Sound_file_config;
 using Roan_trail::Long_int;
 using namespace Roan_trail::Builder;
 
@@ -69,35 +74,6 @@ namespace
   const double ic_estimate_multiple_movie_factor = 1.01;
 }
 
-//
-// Constructor/destructor/initialization
-//
-
-Movie_builder::Movie_builder(const Movie_builder_config& config, const Movie_builder_model& model)
-  : m_video_frame_cache(0),
-    m_config(config),
-    m_model(model),
-    m_logger(Logger::default_logger()),
-    m_sound_builder(new Sound_builder),
-    m_setup(false),
-    m_running(false),
-    m_total_destination_count(0),
-    m_current_segment_index(0),
-    m_total_fraction_completed(0.0),
-    m_dest_frames_added(0),
-    m_segment_count(0),
-    m_current_segment_video_start_frame(0),
-    m_current_segment_video_duration(0),
-    m_video_frames_per_reference_frame(0.0),
-    m_movie(new Movie(*m_config.movie)),
-    m_output_movies(),
-    m_movie_file_name(),
-    m_movie_paths(),
-    m_temporary_paths()
-{
-  postcondition(mf_invariant(false));
-}
-
 Movie_builder::~Movie_builder()
 {
   precondition(mf_invariant(false));
@@ -107,7 +83,7 @@ Movie_builder::~Movie_builder()
 }
 
 //
-//
+// Other member functions
 //
 
 Long_int Movie_builder::total_video_frames(const vector<Segment>& segments,
@@ -211,7 +187,7 @@ bool Movie_builder::setup(Error_param& return_error)
                  // failure
                  || (!return_value && !m_setup))
                 && !m_running
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 
@@ -284,9 +260,10 @@ bool Movie_builder::start(Error_param& return_error)
  exit_point:
   postcondition(// success
                 ((return_value && m_running)
+                 // failure
                  || (!return_value && !m_running))
                 && m_setup
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -327,13 +304,15 @@ bool Movie_builder::add_next_segment(bool& return_more_segments, Error_param& re
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
   postcondition(m_setup
                 && m_running
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -395,7 +374,7 @@ bool Movie_builder::stop(bool completed, Error_param& return_error)
  exit_point:
   postcondition(m_setup
                 && !m_running
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -491,7 +470,7 @@ bool Movie_builder::end(bool completed,
  exit_point:
   postcondition(m_setup
                 && !m_running
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -568,7 +547,14 @@ Long_int Movie_builder::estimate_build_size()
   const size_t middle = segments.size() / 2;
   const Segment& middle_segment = segments[middle];
   // cache the image from the source
-  mf_generate_image(middle_segment.index());
+  bool default_used;
+  mf_generate_image(middle_segment.index(), default_used);
+  if (default_used)
+  {
+    m_logger << Logger::warning;
+    m_logger << "When estimating build size, image for slide " << middle_segment.index() + 1;
+    m_logger << " not found, using default image" << endl;
+  }
   // use the cache as the sample frame
   const uint8_t* raw_frame = m_video_frame_cache;
   const Long_int video_frame_size = m_movie->estimate_video_frame_size(raw_frame);
@@ -601,6 +587,35 @@ Long_int Movie_builder::estimate_build_size()
 // Protected member functions
 //
 
+Movie_builder::Movie_builder(const Movie_builder_config& config, const Movie_builder_model& model)
+  : m_video_frame_cache(0),
+    m_config(config),
+    m_model(model),
+    m_logger(Logger::default_logger()),
+    m_sound_builder(new Sound_builder),
+    m_setup(false),
+    m_running(false),
+    m_total_destination_count(0),
+    m_current_segment_index(0),
+    m_total_fraction_completed(0.0),
+    m_dest_frames_added(0),
+    m_segment_count(0),
+    m_current_segment_video_start_frame(0),
+    m_current_segment_video_duration(0),
+    m_video_frames_per_reference_frame(0.0),
+    m_movie(new Movie(*m_config.movie)),
+    m_output_movies(),
+    m_movie_file_name(),
+    m_movie_paths(),
+    m_temporary_paths()
+{
+  postcondition(mf_invariant(false));
+}
+
+//
+//   Invariant
+//
+
 bool Movie_builder::mf_invariant(bool check_base_class) const
 {
   bool return_value = false;
@@ -742,7 +757,7 @@ bool Movie_builder::mf_move_movies_atomically(vector<Error_param>& return_warnin
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error()));
+  postcondition(return_error.is_valid_at_return(return_value));
   return return_value;
 }
 
@@ -794,7 +809,14 @@ bool Movie_builder::mf_add_segment_to_single_movie(Error_param& return_error)
   // cache the image from the source
   m_logger << Logger::info;
   m_logger << "Loading image for segment" << endl;
-  mf_generate_image(current_segment.index());
+  bool default_used;
+  mf_generate_image(current_segment.index(), default_used);
+  if (default_used)
+  {
+    m_logger << Logger::warning;
+    m_logger << "When adding segment, image for slide " << current_segment.index() + 1;
+    m_logger << " not found, using default image" << endl;
+  }
   // use the cache
   const uint8_t* raw_frame = m_video_frame_cache;
 
@@ -845,11 +867,13 @@ bool Movie_builder::mf_add_segment_to_single_movie(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error()));
+  postcondition(return_error.is_valid_at_return(return_value));
   return return_value;
 }
 
@@ -896,7 +920,14 @@ bool Movie_builder::mf_add_segment_to_multiple_movies(Error_param& return_error)
 
   // cache the image from the source
   m_logger << Logger::info << "Loading image for segment" << endl;
-  mf_generate_image(current_segment.index());
+  bool default_used;
+  mf_generate_image(current_segment.index(), default_used);
+  if (default_used)
+  {
+    m_logger << Logger::warning;
+    m_logger << "When adding segment, image for slide " << current_segment.index() + 1;
+    m_logger << " not found, using default image" << endl;
+  }
   // use the cache
   const uint8_t* raw_frame = m_video_frame_cache;
 
@@ -975,7 +1006,7 @@ bool Movie_builder::mf_add_segment_to_multiple_movies(Error_param& return_error)
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error()));
+  postcondition(return_error.is_valid_at_return(return_value));
   return return_value;
 }
 
@@ -1078,10 +1109,12 @@ bool Movie_builder::mf_check_source_audio_sample_rate(Error_param &return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition(return_value || !return_error.need_error() || return_error());
+  postcondition(return_error.is_valid_at_return(return_value));
   return return_value;
 }
