@@ -27,10 +27,14 @@
 #include <libxml++/nodes/element.h>
 #include <libxml++/nodes/node.h>
 #include <libxml2/libxml/tree.h>
+#include <string>
 #include <sstream>
+#include <vector>
 
-using std::stringstream;
 using std::endl;
+using std::string;
+using std::stringstream;
+using std::vector;
 using xmlpp::Element;
 using xmlpp::Node;
 using Roan_trail::Long_int;
@@ -114,11 +118,13 @@ bool Narration_recorder::startup(Sound_recorder_config& config, Error_param& ret
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error())
+  postcondition(return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -173,7 +179,7 @@ bool Narration_recorder::shutdown(Error_param& return_error)
 
  exit_point:
   postcondition((Recorder::state_stopped == state())
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -216,14 +222,14 @@ bool Narration_recorder::pause(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((return_value
-                 // function failure
-                 || (!return_value && (!return_error.need_error() || return_error())))
-                 && mf_invariant());
+  postcondition(return_error.is_valid_at_return(return_value)
+                && mf_invariant());
   return return_value;
 }
 
@@ -255,15 +261,15 @@ bool Narration_recorder::stop(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition(((return_value &&
-                  // function success
-                  (Recorder::state_stopped == state()))
-                 // function failure
-                 ||  (!return_value && (!return_error.need_error() || return_error())))
+  postcondition(((return_value && (Recorder::state_stopped == state()))
+                 || !return_value)
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -317,11 +323,13 @@ bool Narration_recorder::record(Long_int index, Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error())
+  postcondition(return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -350,7 +358,9 @@ bool Narration_recorder::new_index(Long_int index, Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
@@ -382,7 +392,9 @@ bool Narration_recorder::retake(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
@@ -412,11 +424,13 @@ bool Narration_recorder::mute(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error())
+  postcondition(return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -534,11 +548,13 @@ bool Narration_recorder::frames(Long_int& return_total_frames,
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error()));
+  postcondition(return_error.is_valid_at_return(return_value));
   return return_value;
 }
 
@@ -600,11 +616,13 @@ bool Narration_recorder::segments(vector<Segment>& return_segments, Error_param&
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error()));
+  postcondition(return_error.is_valid_at_return(return_value));
   return return_value;
 }
 
@@ -812,7 +830,9 @@ bool Narration_recorder::export_as_XML(const string& file_path,
   goto exit_point;
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
