@@ -32,17 +32,20 @@
 #include "error/Posix_error.hpp"
 #include <boost/integer_traits.hpp>
 #include <portaudio.h>
+#include <iomanip>
 #include <iostream>
 #include <sstream>
-#include <iomanip>
+#include <string>
+#include <vector>
+#include <cerrno> // Standards Rule 17 exception (check_code_ignore)
 #include <cmath>
 #include <cstring>
-#include <cerrno> // Standards Rule 17 exception (check_code_ignore)
-#include <strings.h>
 
 using std::cerr;
 using std::endl;
+using std::string;
 using std::stringstream;
+using std::vector;
 using boost::integer_traits;
 using Roan_trail::Long_int;
 using Roan_trail::Error;
@@ -539,7 +542,9 @@ bool Sound_recorder::startup(const Sound_recorder_config& config, Error_param& r
     size_t muted_buffer_size = sizeof(Stream_float) * number_channels * frames_per_buffer;
 
     m_muted_buffer = new char[muted_buffer_size];
-    bzero(m_muted_buffer, muted_buffer_size);
+    memset(m_muted_buffer,
+           0,
+           muted_buffer_size);
 
     PA_error = Pa_StartStream(m_PA_stream);
     on_error(paNoError != PA_error, new Record_error(error_location(),
@@ -644,25 +649,25 @@ bool Sound_recorder::startup(const Sound_recorder_config& config, Error_param& r
   goto exit_point;
 
  exit_point:
-  postcondition(((return_value &&
-                  // function success
+  postcondition(( // function success
+                 (return_value &&
                   ((m_PA_stream && Pa_IsStreamActive(m_PA_stream))
                    && (m_AAFW && m_AAFW->running())
                    && (*m_config == new_config)
                    && m_level_RMS
                    && m_level_peak
                    && m_muted_buffer
-                   && m_sound_initialized)) ||
-                 (!return_value &&
-                  // function failure
-                  (!m_PA_stream
-                   && !m_AAFW
-                   && (*m_config == old_config)
-                   && !m_level_RMS
-                   && !m_level_peak
-                   && !m_muted_buffer
-                   && !m_sound_initialized
-                   && (!return_error.need_error() || return_error()))))
+                   && m_sound_initialized))
+                 // function failure
+                 || (!return_value &&
+                     (!m_PA_stream
+                      && !m_AAFW
+                      && (*m_config == old_config)
+                      && !m_level_RMS
+                      && !m_level_peak
+                      && !m_muted_buffer
+                      && !m_sound_initialized)))
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -784,7 +789,7 @@ bool Sound_recorder::shutdown(Error_param& return_error)
                 && !m_PA_stream
                 && !m_AAFW
                 && !m_sound_initialized
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -803,9 +808,9 @@ bool Sound_recorder::record(Error_param& return_error)
   start_error_block();
 
   const bool have_error = !can_record();
-  on_error(have_error,new Record_error(error_location(),
-                                       Record_error::record,
-                                       string("Error, recorder cannot start recording")));
+  on_error(have_error, new Record_error(error_location(),
+                                        Record_error::record,
+                                        string("Error, recorder cannot start recording")));
 
   Recorder::record();
 
@@ -817,17 +822,19 @@ bool Sound_recorder::record(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((// function success
+  postcondition(( // function success
                  (return_value
                   && !is_monitoring()
                   && m_have_recording)
-                  //function failure
-                 || (!return_value
-                     && (!return_error.need_error() || return_error())))
+                 //function failure
+                 || !return_value)
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -865,7 +872,9 @@ bool Sound_recorder::pause(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
@@ -873,7 +882,8 @@ bool Sound_recorder::pause(Error_param& return_error)
                  (return_value
                   && is_monitoring())
                  // function failure
-                 || (!return_value && (!return_error.need_error() || return_error())))
+                 || !return_value)
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -996,21 +1006,21 @@ bool Sound_recorder::stop(Error_param& return_error)
   goto exit_point;
 
  exit_point:
-  postcondition(((return_value &&
-                  // function success
+  postcondition(( // function success
+                 (return_value &&
                   ((m_config->file_overwrite &&
                     // overwrite
                     ((m_PA_stream && Pa_IsStreamActive(m_PA_stream))
-                     && (m_AAFW && m_AAFW->running()))) ||
-                   (!m_config->file_overwrite &&
-                    // no overwrite
-                    (!m_PA_stream
-                     && (m_AAFW && !m_AAFW->running()))))) ||
+                     && (m_AAFW && m_AAFW->running())))
+                   || (!m_config->file_overwrite &&
+                       // no overwrite
+                       (!m_PA_stream
+                        && (m_AAFW && !m_AAFW->running())))))
                  // function failure
-                 (!return_value
-                  && (!m_PA_stream
-                      && (m_AAFW && !m_AAFW->running()))
-                  && (!return_error.need_error() || return_error())))
+                 || (!return_value
+                     && (!m_PA_stream
+                         && (m_AAFW && !m_AAFW->running()))))
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -1041,11 +1051,13 @@ bool Sound_recorder::mute(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error())
+  postcondition(return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -1486,7 +1498,7 @@ void Sound_recorder::clear_record_error()
 //
 
 // removes 0 (audio frame) length temporary files,
-// which are created during startup and befoe the record command
+// which are created during startup and before the record command
 // to improve record startup time
 //
 // returns true if one is removed
