@@ -24,6 +24,7 @@
 #include "error/Build_error.hpp"
 
 using Roan_trail::Long_int;
+using Roan_trail::Recorder::Sound_file_config;
 using namespace Roan_trail::Builder;
 
 //
@@ -214,13 +215,13 @@ bool Sound_track::setup(AVFormatContext* format_context, Error_param& return_err
   goto exit_point;
 
  exit_point:
-  postcondition(// success
-                ((return_value
+  postcondition(( // success
+                 (return_value
                   && m_setup
                   && m_codec_context)
                  // failure
                  || !return_value)
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -318,13 +319,15 @@ bool Sound_track::add(Long_int reference_start_frame,
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
   postcondition(m_setup
                 && m_started
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -371,13 +374,15 @@ bool Sound_track::add_silence(Long_int reference_frame_count, Error_param& retur
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
   postcondition(m_setup
                 && m_started
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -544,13 +549,15 @@ bool Sound_track::mf_write_frames(const uint8_t* output_buffer,
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
   postcondition(m_setup
                 && m_started
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
