@@ -16,10 +16,11 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
+#include "Kinetophone_build_manager.hpp"
+
 // include *mm first to avoid conflicts
 #include <gdkmm/pixbuf.h>
 
-#include "Kinetophone_build_manager.hpp"
 #include "Kinetophone_builder_config.hpp"
 #include "Kinetophone_builder_model.hpp"
 #include "Kinetophone_movie_builder.hpp"
@@ -36,8 +37,10 @@
 #include "../base/Sound_track.hpp"
 #include "../base/error/Kinetophone_error.hpp"
 #include "../base/error/Build_error.hpp"
-#include <sstream>
 #include <iomanip>
+#include <sstream>
+#include <string>
+#include <vector>
 
 using Glib::RefPtr;
 using Gdk::Pixbuf;
@@ -46,6 +49,8 @@ using std::endl;
 using std::ios_base;
 using std::setfill;
 using std::setw;
+using std::string;
+using std::vector;
 using Roan_trail::Logger;
 using Roan_trail::Recorder::Segment;
 using Roan_trail::Source::Slide;
@@ -98,13 +103,14 @@ bool Kinetophone_build_manager::setup_for_build(Error_param& return_error)
   precondition(!return_error()
                && mf_invariant());
 
+  Kinetophone_movie_builder* movie_builder = 0;
   bool return_value = false;
 
   start_error_block();
 
   m_logger << Logger::info << "Setting up for build." << endl;
 
-  Kinetophone_movie_builder* movie_builder = new Kinetophone_movie_builder(m_config, m_model);
+  movie_builder = new Kinetophone_movie_builder(m_config, m_model);
 
   Error_param error;
   const bool movie_builder_setup = movie_builder->setup(error);
@@ -125,11 +131,22 @@ bool Kinetophone_build_manager::setup_for_build(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler(return_error);
+
+ error_cleanup:
+  if (!return_error.need_error())
+  {
+    delete handler_error;
+  }
+  if (!movie_builder)
+  {
+    delete movie_builder;
+  }
+  return_value = false;
   goto exit_point;
 
  exit_point:
-  postcondition((return_value || !return_error.need_error() || return_error())
+  postcondition(return_error.is_valid_at_return(return_value)
                 && mf_invariant());
   return return_value;
 }
@@ -147,9 +164,10 @@ bool Kinetophone_build_manager::prebuild_checks(Error_param& return_error)
   bool return_value = false;
   bool have_warning = false;
 
+  m_logger << Logger::info << "Estimating build size:" << endl;
   const Long_int build_size_estimate = m_movie_builder->estimate_build_size()
     * ic_build_estimate_factor;
-  m_logger << Logger::info << "Estimated build size: " << build_size_estimate << " (bytes) " << endl;
+  m_logger << Logger::info << "Movie(s) will use approximately " << build_size_estimate << " (bytes) " << endl;
   if (!m_config.movie_builder_config->skip_build_warnings)
   {
     // check for output directory accessibility
@@ -376,7 +394,7 @@ bool Kinetophone_build_manager::build(Error_param& return_error)
   warnings.clear();
 
   postcondition(!warnings.size()
-                && (return_value || !return_error.need_error() || return_error())
+                && return_error.is_valid_at_return(return_value)
                 && mf_invariant());
 
   __sync_and_and_fetch(&m_running, 0x0);
@@ -468,7 +486,6 @@ void Kinetophone_build_manager::mf_log_config(const Kinetophone_movie_builder& b
 {
   m_logger << Logger::info;
   m_logger << "Session info loaded from: " << m_config.session_file_path << endl;
-  m_logger << "Images loaded from: " << m_config.image_directory << endl;
 
   // source sound file
   const Sound_file_config& sound_config = builder.sound_builder().config();
@@ -570,6 +587,7 @@ void Kinetophone_build_manager::mf_log_model(const Kinetophone_movie_builder& bu
   m_logger << Logger::info;
   m_logger << "Session" << endl;
   m_logger << "-------" << endl;
+  m_logger << "  images loaded from: " << m_model.slides()->source() << endl;
   // audio sample rate
   const Long_int original_sample_rate = m_model.audio_recording_frame_rate();
   m_logger << "  original audio sample rate: " << original_sample_rate << endl;;
