@@ -27,22 +27,30 @@
 #include <boost/program_options.hpp>
 #include <boost/concept/assert.hpp>
 #include <boost/concept_check.hpp>
-#include <iomanip>
-#include <sstream>
+#include <exception>
 #include <fstream>
+#include <iomanip>
 #include <istream>
+#include <sstream>
+#include <string>
 #include <cstdlib>
 
 using std::endl;
+using std::exception;
 using std::hex;
 using std::ifstream;
 using std::istream;
 using std::ios_base;
+using std::logic_error;
+using std::ostream;
 using std::setfill;
 using std::setw;
+using std::string;
 using std::stringstream;
+using std::vector;
 using Roan_trail::Color;
 using Roan_trail::File_manager;
+using Roan_trail::Builder::Movie_builder_config;
 using namespace Roan_trail::Kinetophone;
 
 namespace PO = boost::program_options;
@@ -85,7 +93,7 @@ namespace
   }
 
   void validate(boost::any& v,
-                const std::vector<std::string>& values,
+                const vector<string>& values,
                 Ih_validator<bool>*, int)
   {
     using namespace PO;
@@ -128,7 +136,7 @@ namespace
   }
 
   template<class T, Ih_lookup_ptr F> void validate(boost::any& v,
-                const std::vector<std::string>& values,
+                const vector<string>& values,
                 Ih_lookup_validator<T, F>*, int)
   {
     using namespace PO;
@@ -164,7 +172,7 @@ namespace
   }
 
   template<class T, int i> void validate(boost::any& v,
-                                         const std::vector<std::string>& values,
+                                         const vector<string>& values,
                                          Ih_cond_validator<T, i>*, int)
   {
     using namespace PO;
@@ -283,46 +291,31 @@ namespace
       string use_movie_preset = movie_builder_config.movie.movie_preset.v;
       if ("" == use_movie_preset)
       {
-        if ("" != movie_builder_config.output.movie_name)
+        // movie preset not specified
+        // try to determine from output file extension
+        const string extension = File_manager::file_extension_for_file
+          (movie_builder_config.output.movie_name);
+        if ("" != extension)
         {
-          // movie preset not specified, but output movie name is
-          // try to determine from output file extension
-          const string extension = File_manager::file_extension_for_file
-            (movie_builder_config.output.movie_name);
           Movie_config::movie_preset_string_for_file_extension(extension, use_movie_preset);
         }
-      }
-      if ("" == use_movie_preset)
-      { // still blank, use default movie preset
-        use_movie_preset =
-          Movie_config::string_for_movie_preset(Movie_config::default_movie_preset);
+        else
+        {
+          // no extension, use default
+          use_movie_preset =
+            Movie_config::string_for_movie_preset(Movie_config::default_movie_preset);
+        }
       }
       if (!Movie_config::movie_preset_for_string(use_movie_preset,
                                                  return_cfg.movie_builder_config->movie->movie_preset))
       {
-        assert(false && "invalid movie preset string");
+        // not an an understood preset, this will be an error
+        return_cfg.movie_builder_config->movie->movie_preset = Movie_config::movie_preset_unknown;
       }
-      //  sound format from sound file
-      string use_sound_format = movie_builder_config.movie.sound.file_type.v;
-      if ("" == use_sound_format)
-      {
-        if ("" != movie_builder_config.movie.sound.file_name)
-        {
-          // file type not specified, but output file is
-          // try to determine from output file extension
-          use_sound_format = File_manager::file_extension_for_file
-            (movie_builder_config.movie.sound.file_name);
-        }
-      }
-      if ("" == use_sound_format)
-      { // still blank, use default sound format
-        use_sound_format =
-          Sound_file_config::string_for_file_type(Sound_file_config::default_file_type);
-      }
-      if (!Sound_file_config::file_type_for_string(use_sound_format,
+      if (!Sound_file_config::file_type_for_string(movie_builder_config.movie.sound.file_type.v,
                                                    return_cfg.movie_builder_config->movie->sound->file_type))
-      {
-        assert(false && "invalid file type string");
+      { // use default file type
+        return_cfg.movie_builder_config->movie->sound->file_type = Sound_file_config::default_file_type;
       }
       if (!Sound_file_config::data_format_for_string(movie_builder_config.movie.sound.data_format.v,
                                                      return_cfg.movie_builder_config->movie->sound->data_format))
@@ -370,7 +363,7 @@ namespace
       struct Movie_validator_struct
       {
         Movie_validator_struct(const Movie_config& m)
-          : movie_preset(Ih_movie_preset_validator(Movie_config::string_for_movie_preset(m.movie_preset))),
+          : movie_preset(Ih_movie_preset_validator("")),
             frame_rate(Ih_frame_rate_type_validator(Movie_config::string_for_frame_rate_type(m.frame_rate))),
             frame_format(Ih_frame_format_validator(Movie_config::
                                                    string_for_frame_format(m.frame_format))),
@@ -380,7 +373,7 @@ namespace
         {
           if (!Movie_config::movie_preset_for_string(movie_preset.v, return_m.movie_preset))
           {
-            assert(false && "invalid movie preset string");
+            return_m.movie_preset = Movie_config::movie_preset_unknown;
           }
           if (!Movie_config::frame_rate_type_for_string(frame_rate.v, return_m.frame_rate))
           {
@@ -521,7 +514,7 @@ namespace
         exception_message += string(": ") + message;
       }
       exception_message += ".";
-      throw std::logic_error(exception_message);
+      throw logic_error(exception_message);
     }
   }
 
@@ -541,8 +534,8 @@ namespace
           || VM[required_option].defaulted()
           || !condition)
       {
-        throw std::logic_error(string("option '") + for_what
-                               + "' requires option '" + required_option + "'.");
+        throw logic_error(string("option '") + for_what
+                          + "' requires option '" + required_option + "'.");
       }
     }
   }
@@ -550,6 +543,7 @@ namespace
   void ih_check_option_consistency(const Kinetophone_builder_config& cfg,
                                    const PO::variables_map& VM)
   {
+    // conflicting option checks
     ih_check_conflicting_options(VM,
                                  "output-directory",
                                  "movie-name",
@@ -569,13 +563,21 @@ namespace
     ih_check_conflicting_options(VM,
                                  "skip-build-warnings",
                                  "quit-on-prebuild-warnings");
+    // required option checks
     if ("" == cfg.session_file_path)
     {
-      throw std::logic_error(string("session file not specified"));
+      throw logic_error(string("session file not specified"));
     }
+    // option dependency checks
     ih_check_option_dependency(VM,
                                "silence-gap-length",
                                "silence-gaps");
+
+    // invalid movie preset
+    if (Movie_config::movie_preset_unknown == cfg.movie_builder_config->movie->movie_preset)
+    {
+      throw logic_error("could not determine a movie preset");
+    }
   }
 
   typedef struct
@@ -703,7 +705,7 @@ Kinetophone_builder_config::Kinetophone_builder_config()
   // setup some reasonable defaults
   : help_message(""),
     session_file_path(),
-    image_directory("."),
+    image_directory(""), // left blank to indicate that the directory in the session file should be used
     movie_builder_config(new Movie_builder_config),
     detailed_error(false),
     quit_on_prebuild_warnings(false),
@@ -814,11 +816,11 @@ int Kinetophone_builder_config::parse_program_options(int argc,
       return_value = Kinetophone_builder_config::command_build;
     }
   }
-  catch (const std::exception& e)
+  catch (const exception& e)
   {
     string diagnostic = e.what();
     stringstream s;
-    s << "Reason: " << diagnostic << std::endl << std::endl;
+    s << "Reason: " << diagnostic << endl << endl;
     s << "Enter kinetophone_builder --help for valid program options.";
     Kinetophone_error* error = new Kinetophone_error(error_location(),
                                                      Kinetophone_error::command_line,
