@@ -1,6 +1,6 @@
 // Console_controller.hpp
 //
-// Copyright 2011 Roan Trail, Inc.
+// Copyright 2011-2012 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,25 +16,22 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
+// Abstract base, console controller class
+
 #ifndef CONSOLE_CONTROLLER_HPP_
 #define CONSOLE_CONTROLLER_HPP_
 
-#include <vector>
-
-using std::vector;
-
 namespace Roan_trail
 {
-  class Error;
   class Error_param;
 
   class Console_controller
   {
   public:
-    Console_controller() {}
     virtual ~Console_controller() {}
     virtual bool process_input(bool& return_done, Error_param& return_error) = 0;
   protected:
+    Console_controller() {}
     // invariant check
     bool mf_invariant(bool check_base_class = true) const;
   private:
