@@ -18,7 +18,9 @@
 
 #include "Kinetophone_dbus_client.hpp"
 #include "../base/common.hpp"
+#include <dbus-c++/dbus.h>
 
+using DBus::Connection;
 using namespace Roan_trail::Kinetophone;
 
 //
