@@ -26,13 +26,19 @@
 #include <boost/program_options.hpp>
 #include <boost/concept/assert.hpp>
 #include <boost/concept_check.hpp>
-#include <sstream>
 #include <fstream>
+#include <iostream>
+#include <sstream>
+#include <string>
+#include <vector>
 #include <cstdlib>
 
 using std::stringstream;
 using std::ifstream;
 using std::endl;
+using std::ostream;
+using std::string;
+using std::vector;
 using Roan_trail::File_manager;
 using Roan_trail::Recorder::Sound_file_config;
 using namespace Roan_trail::Kinetophone;
@@ -272,19 +278,20 @@ namespace
         {
           // file type not specified, but output file is
           // try to determine from output file extension
-          use_file_type = File_manager::file_extension_for_file
-            (sound_recorder_config.sound_file.file_name);
+          use_file_type = File_manager::file_extension_for_file(sound_recorder_config.sound_file.file_name);
+        }
+        else
+        {
+          // neither specified, use default
+          use_file_type =
+            Sound_file_config::string_for_file_type(Sound_file_config::default_file_type);
         }
-      }
-      if ("" == use_file_type)
-      { // still blank, use default file type
-        use_file_type =
-          Sound_file_config::string_for_file_type(Sound_file_config::default_file_type);
       }
       if (!Sound_file_config::file_type_for_string(use_file_type,
                                                    return_cfg.sound_recorder_config->sound_file->file_type))
       {
-        assert(false && "invalid file type string");
+        // not an an understood file type, this will be an error
+        return_cfg.sound_recorder_config->sound_file->file_type = Sound_file_config::file_type_unknown;
       }
       if (!Sound_file_config::data_format_for_string(sound_recorder_config.sound_file.data_format.v,
                                                      return_cfg.sound_recorder_config->sound_file->data_format))
@@ -355,7 +362,7 @@ namespace
             sample_rate(Ih_pos_int_validator(static_cast<int>(s.sample_rate))),
             VBR_quality(Ih_fraction_validator(s.VBR_quality)),
             file_name(s.file_name),
-            file_type(Ih_file_type_validator(Sound_file_config::string_for_file_type(s.file_type))),
+            file_type(Ih_file_type_validator("")),
             data_format(Ih_data_format_validator(Sound_file_config::string_for_data_format(s.data_format))),
             endianness(Ih_endianness_validator(Sound_file_config::string_for_endianness(s.endianness))) {}
         void update(Sound_file_config& return_s)
@@ -366,7 +373,7 @@ namespace
           return_s.file_name = file_name;
           if (!Sound_file_config::file_type_for_string(file_type.v, return_s.file_type))
           {
-            assert(false && "invalid file type string");
+            return_s.file_type = Sound_file_config::file_type_unknown;
           }
           if (!Sound_file_config::data_format_for_string(data_format.v, return_s.data_format))
           {
@@ -462,6 +469,11 @@ namespace
                                "level-meter-decay-period",
                                "level-meter-ballistics",
                                cfg.level_meter.model_ballistics);
+    // invalid file type
+    if (Sound_file_config::file_type_unknown == cfg.sound_recorder_config->sound_file->file_type)
+    {
+      throw std::logic_error("could not determine a valid sound file type");
+    }
   }
 
   typedef struct
@@ -680,7 +692,7 @@ int Kinetophone_narrator_config::parse_program_options(int argc,
     // parse the command line (overrides config file)
     PO::positional_options_description pos_desc;
     pos_desc.add("image-directory", 1);
-    pos_desc.add("sound-file", 2);
+    pos_desc.add("sound-file", 1);
     PO::store(PO::command_line_parser(argc, const_cast<char**>(argv)).
               options(all_desc).positional(pos_desc).run(), VM);
     PO::notify(VM);
