@@ -16,6 +16,8 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
+#include "Kinetophone_narrator_view.hpp"
+
 // include *mm first to avoid conflicts
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/aspectframe.h>
@@ -32,7 +34,6 @@
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/toggletoolbutton.h>
 
-#include "Kinetophone_narrator_view.hpp"
 #include "Kinetophone_narrator_model.hpp"
 #include "Kinetophone_narrator_config.hpp"
 #include "Kinetophone_narrator_window.hpp"
@@ -51,6 +52,9 @@
 #include <iostream>
 #include <iomanip>
 #include <sstream>
+#include <string>
+#include <utility>
+#include <vector>
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -64,15 +68,26 @@
 #define PACKAGE_URL "unknown"
 #endif
 
+using Glib::RefPtr;
+using Gdk::Pixbuf;
 using Gtk::AboutDialog;
 using Gtk::Clipboard;
+using Gtk::ComboBoxText;
 using Gtk::FileChooserDialog;
+using Gtk::HButtonBox;
 using Gtk::InfoBar;
 using Gtk::Image;
 using Gtk::MessageDialog;
+using Gtk::TextView;
+using Gtk::ToggleButton;
+using Gtk::ToggleToolButton;
 using std::cout;
 using std::cerr;
+using std::endl;
+using std::pair;
+using std::string;
 using std::stringstream;
+using std::vector;
 using sigc::bind;
 using sigc::connection;
 using sigc::mem_fun;
@@ -114,6 +129,8 @@ Kinetophone_narrator_view::Kinetophone_narrator_view(const Kinetophone_narrator_
     m_pause_signal(),
     m_record_signal(),
     m_toggle_metering_signal(),
+    m_reset_overflow_counts_signal(),
+    m_reset_clipped_signal(),
     m_notes_changed_signal(),
     m_notes_editing_done_signal(),
     m_export_session_signal(),
@@ -459,6 +476,15 @@ void Kinetophone_narrator_view::toggle_metering()
   postcondition(mf_invariant());
 }
 
+void Kinetophone_narrator_view::reset_clipped()
+{
+  precondition(mf_invariant());
+
+  m_main_window->audio_level_meter_widget()->reset_clipped();
+
+  postcondition(mf_invariant());
+}
+
 void Kinetophone_narrator_view::show_session_info(const string& message)
 {
   m_main_window->session_info_label()->set_text(message);
@@ -539,7 +565,9 @@ bool Kinetophone_narrator_view::list_devices(Error_param& return_error)
 
   end_error_block();
 
-  default_error_handler_and_cleanup(return_error, return_value, false);
+  default_error_handler_and_cleanup(return_error,
+                                    return_value,
+                                    false);
   goto exit_point;
 
  exit_point:
@@ -565,25 +593,30 @@ bool Kinetophone_narrator_view::mf_invariant(bool check_base_class) const
     goto exit_point;
   }
 
-  // all signals should be connected and connections active after setup
-  if (m_setup
-      && (m_retake_signal.empty()
-          || m_previous_signal.empty()
-          || m_slide_signal.empty()
-          || m_next_signal.empty()
-          || m_mute_signal.empty()
-          || m_pause_signal.empty()
-          || m_record_signal.empty()
-          || m_toggle_metering_signal.empty()
-          || m_notes_changed_signal.empty()
-          || m_notes_editing_done_signal.empty()
-          || m_export_session_signal.empty()
-          || m_quit_signal.empty()
-          || m_pause_toggle_connection.empty()
-          || m_slide_connection.empty()
-          || m_slide_notes_connection.empty()))
+
+  if (m_setup)
   {
-    goto exit_point;
+    // all signals should be connected and connections active after setup
+    if (m_retake_signal.empty()
+        || m_previous_signal.empty()
+        || m_slide_signal.empty()
+        || m_next_signal.empty()
+        || m_mute_signal.empty()
+        || m_pause_signal.empty()
+        || m_record_signal.empty()
+        || m_toggle_metering_signal.empty()
+        || m_reset_overflow_counts_signal.empty()
+        || m_reset_clipped_signal.empty()
+        || m_notes_changed_signal.empty()
+        || m_notes_editing_done_signal.empty()
+        || m_export_session_signal.empty()
+        || m_quit_signal.empty()
+        || m_pause_toggle_connection.empty()
+        || m_slide_connection.empty()
+        || m_slide_notes_connection.empty())
+    {
+      goto exit_point;
+    }
   }
 
   return_value = true;
@@ -716,6 +749,8 @@ void Kinetophone_narrator_view::mf_connect_signals()
   m_main_window->record_toggle_tool_button()->signal_toggled().connect(m_record_signal.make_slot());
   m_main_window->level_toggle_button()->signal_toggled().connect(m_toggle_metering_signal.make_slot());
   // connect signals which need custom slots
+  m_main_window->signal_key_press_event().
+    connect(mem_fun(*this, &Kinetophone_narrator_view::mf_main_window_key_pressed));
   m_main_window->mute_toggle_tool_button()->signal_toggled().
     connect(mem_fun(*this, &Kinetophone_narrator_view::mf_mute));
   m_slide_connection = m_main_window->slide_combo_box_text()->signal_changed().
@@ -775,6 +810,65 @@ void Kinetophone_narrator_view::mf_setup_thumbnail_browser()
 // slots
 //
 
+bool Kinetophone_narrator_view::mf_main_window_key_pressed(GdkEventKey* event)
+{
+  bool return_value = false;
+
+  const guint modifiers = gtk_accelerator_get_default_mod_mask();
+
+  if (GDK_CONTROL_MASK == (event->state & modifiers))
+  {
+    switch (event->keyval)
+    {
+    case GDK_l: // CTRL-l resets level meter clipped indicator
+      m_reset_clipped_signal.emit();
+      return_value = true;
+      break;
+    case GDK_m: // CTRL-m toggles mute
+      {
+        ToggleToolButton* mute_button = m_main_window->mute_toggle_tool_button();
+        if (mute_button->get_sensitive())
+        {
+          // simulate click of button, because the mute button isn't updated when the recorder
+          // is updated
+          mute_button->set_active(!mute_button->get_active());
+        }
+      }
+      return_value = true;
+      break;
+    case GDK_o: // CTRL-o resets overflow counts
+      m_reset_overflow_counts_signal.emit();
+      return_value = true;
+      break;
+    case GDK_p: // CTRL-p toggles pause
+      {
+        ToggleToolButton* pause_button = m_main_window->pause_toggle_tool_button();
+        if (pause_button->get_sensitive())
+        {
+          // simulate click of button, because the pause button isn't updated when the recorder
+          // is updated
+          pause_button->set_active(!pause_button->get_active());
+        }
+      }
+      return_value = true;
+      break;
+    case GDK_r: // CTRL-r toggles recording
+      if (m_main_window->record_toggle_tool_button()->get_sensitive())
+      {
+        // just need to emit the record signal, because the record button is updated when the recorder
+        // is updated
+        m_record_signal.emit();
+      }
+      return_value = true;
+      break;
+    default:
+      break;
+    }
+  }
+
+  return return_value;
+}
+
 void Kinetophone_narrator_view::mf_slide()
 {
   int slide_index = m_main_window->slide_combo_box_text()->get_active_row_number();
@@ -816,6 +910,8 @@ void Kinetophone_narrator_view::mf_notes_editing_done()
 
 void Kinetophone_narrator_view::mf_export_session()
 {
+  mf_notes_editing_done();
+
   FileChooserDialog dialog(*m_main_window,
                            "Choose a file to export session (in XML):",
                            Gtk::FILE_CHOOSER_ACTION_SAVE);
@@ -828,7 +924,6 @@ void Kinetophone_narrator_view::mf_export_session()
   switch(result)
   {
   case Gtk::RESPONSE_OK:
-    mf_notes_editing_done();
     m_export_session_signal.emit(dialog.get_filename());
     break;
   default:
