@@ -25,16 +25,20 @@
 //   gtkmm-2.24.2/docs/reference/html/gtk-no.png
 // which are licensed under the Lesser GPL version 2.1.
 
+#include "Kinetophone_narrator_window.hpp"
+
 // include *mm first to avoid conflicts
 #include <gtkmm/accelgroup.h>
 #include <gtkmm/alignment.h>
 #include <gtkmm/aspectframe.h>
-#include <gtkmm/builder.h>
-#include <gtkmm/comboboxtext.h>
 #include <gtkmm/box.h>
+#include <gtkmm/button.h>
 #include <gtkmm/buttonbox.h>
+#include <gtkmm/comboboxtext.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/eventbox.h>
+#include <gtkmm/frame.h>
+#include <gtkmm/image.h>
 #include <gtkmm/imagemenuitem.h>
 #include <gtkmm/infobar.h>
 #include <gtkmm/label.h>
@@ -47,17 +51,16 @@
 #include <gtkmm/separatormenuitem.h>
 #include <gtkmm/statusbar.h>
 #include <gtkmm/stock.h>
-#include <gtkmm/toolbutton.h>
 #include <gtkmm/textview.h>
-#include <gtkmm/toolbar.h>
-#include <gtkmm/toolitem.h>
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/toggletoolbutton.h>
+#include <gtkmm/toolbar.h>
+#include <gtkmm/toolbutton.h>
+#include <gtkmm/toolitem.h>
 #include <gtkmm/viewport.h>
 #include <gtkmm/window.h>
 #include <pangomm/fontdescription.h>
 
-#include "Kinetophone_narrator_window.hpp"
 #include "../base/common.hpp"
 #include "Fraction_bar_widget.hpp"
 #include "Level_meter_widget.hpp"
@@ -67,25 +70,46 @@
 #include "../base/Sound_file_config.hpp"
 #include "../base/error/Kinetophone_error.hpp"
 #include "../base/Application.hpp"
+#include <string>
 
+using Gdk::Color;
+using Glib::RefPtr;
 using Gtk::AccelGroup;
+using Gtk::Alignment;
+using Gtk::AspectFrame;
 using Gtk::Box;
+using Gtk::Button;
+using Gtk::ButtonBox;
+using Gtk::ComboBoxText;
 using Gtk::EventBox;
 using Gtk::Frame;
 using Gtk::HBox;
+using Gtk::HButtonBox;
 using Gtk::HPaned;
+using Gtk::HSeparator;
+using Gtk::Image;
 using Gtk::ImageMenuItem;
+using Gtk::InfoBar;
+using Gtk::Label;
 using Gtk::Menu;
 using Gtk::MenuBar;
+using Gtk::MenuItem;
 using Gtk::ScrolledWindow;
-using Gtk::HSeparator;
 using Gtk::SeparatorMenuItem;
+using Gtk::Statusbar;
+using Gtk::TextView;
+using Gtk::ToggleButton;
+using Gtk::ToggleToolButton;
 using Gtk::Toolbar;
+using Gtk::ToolButton;
+using Gtk::ToolItem;
 using Gtk::VBox;
 using Gtk::Viewport;
+using Gtk::Widget;
 using Pango::FontDescription;
 using sigc::connection;
 using sigc::mem_fun;
+using std::string;
 using namespace Roan_trail::Kinetophone;
 
 //
@@ -342,12 +366,12 @@ Widget* Kinetophone_narrator_window::mf_setup_control_toolbar()
   control_toolbar->set_toolbar_style(Gtk::TOOLBAR_ICONS);
   // retake
   m_retake_tool_button = manage(new ToolButton(Gtk::StockID("gtk-redo"))); // exposed in the class interface
-  m_retake_tool_button->set_tooltip_text("Retake Slide");
+  m_retake_tool_button->set_tooltip_text("Retake Slide (CTRL-<backspace>)");
   m_retake_tool_button->set_is_important();
   control_toolbar->append(*m_retake_tool_button);
   // previous
   m_previous_tool_button = manage(new ToolButton(Gtk::StockID("gtk-go-back"))); // exposed
-  m_previous_tool_button->set_tooltip_text("Previous Slide");
+  m_previous_tool_button->set_tooltip_text("Previous Slide (CTRL-<left arrow>)");
   m_previous_tool_button->set_is_important();
   control_toolbar->append(*m_previous_tool_button);
   // slide combo
@@ -358,7 +382,7 @@ Widget* Kinetophone_narrator_window::mf_setup_control_toolbar()
   slide_combo_tool_item->add(*m_slide_combo_box_text);
   // next
   m_next_tool_button = manage(new ToolButton(Gtk::StockID("gtk-go-forward"))); // exposed
-  m_next_tool_button->set_tooltip_text("Next Slide");
+  m_next_tool_button->set_tooltip_text("Next Slide (CTRL-<right arrow>)");
   m_next_tool_button->set_is_important();
   control_toolbar->append(*m_next_tool_button);
   // separator
@@ -383,13 +407,13 @@ Widget* Kinetophone_narrator_window::mf_setup_control_toolbar()
   record_time_frame->add(*m_record_time_label);
   // mute
   m_mute_toggle_tool_button = manage(new ToggleToolButton); // exposed in class interface
-  m_mute_toggle_tool_button->set_tooltip_text("Toggle Mute");
+  m_mute_toggle_tool_button->set_tooltip_text("Toggle Mute (CTRL-m)");
   m_mute_toggle_tool_button->set_is_important();
   m_mute_toggle_tool_button->set_icon_name("audio-volume-high");
   control_toolbar->append(*m_mute_toggle_tool_button);
   // pause
   m_pause_toggle_tool_button = manage(new ToggleToolButton); // exposed in class interface
-  m_pause_toggle_tool_button->set_tooltip_text("Toggle Pause");
+  m_pause_toggle_tool_button->set_tooltip_text("Toggle Pause (CTRL-p)");
   m_pause_toggle_tool_button->set_is_important();
   m_pause_toggle_tool_button->set_icon_name("gtk-media-pause");
   control_toolbar->append(*m_pause_toggle_tool_button);
@@ -404,7 +428,7 @@ Widget* Kinetophone_narrator_window::mf_setup_control_toolbar()
     manage(new Image(m_record_icon_start->get_pixbuf())); // exposed in class interface
     // button
   m_record_toggle_tool_button = manage(new ToggleToolButton); // exposed in class interface
-  m_record_toggle_tool_button->set_tooltip_text("Toggle Record");
+  m_record_toggle_tool_button->set_tooltip_text("Toggle Record (CTRL-r)");
   m_record_toggle_tool_button->set_is_important();
   m_record_toggle_tool_button->set_icon_widget(*m_record_icon);
   control_toolbar->append(*m_record_toggle_tool_button);
@@ -491,6 +515,7 @@ Widget* Kinetophone_narrator_window::mf_setup_viewer()
   m_notes_text_view = manage(new TextView); // exposed in class interface
   m_notes_text_view->set_can_focus(true);
   m_notes_text_view->set_accepts_tab(false);
+  m_notes_text_view->set_wrap_mode(Gtk::WRAP_WORD);
   notes_scrolled_window->add(*m_notes_text_view);
 
   return viewer_hpaned;
