@@ -16,22 +16,25 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
+#include "Level_meter_widget.hpp"
+
 // include *mm first to avoid conflicts
 #include <gdkmm/drawable.h>
 #include <gdkmm/general.h>
 
-#include "Level_meter_widget.hpp"
 #include "../base/common.hpp"
 #include "../base/Level_meter_view.hpp"
 #include "../base/error/Error.hpp"
-#include <iostream>
+#include <vector>
 #include <cstring>
 
+using Gdk::Color;
+using Gdk::Rectangle;
 using Gdk::Window;
 using Glib::RefPtr;
 using Gtk::Allocation;
 using Gtk::Requisition;
-using Gtk::Button;
+using std::vector;
 using Roan_trail::Error_param;
 using namespace Gdk::Cairo;
 using namespace Roan_trail::Kinetophone;
@@ -59,10 +62,10 @@ namespace
 // Note: The GType name will be gtkmm__CustomObject_Level_meter_widget
 //
 // Note: This shows the GType name, which must be used in the RC file:
-//   std::cout << "GType name: " << G_OBJECT_TYPE_NAME(gobj()) << std::endl;
+//   cout << "GType name: " << G_OBJECT_TYPE_NAME(gobj()) << endl;
 //
 // Note: This show that the GType still derives from GtkWidget:
-//   std::cout << "Gtype is a GtkWidget?:" << GTK_IS_WIDGET(gobj()) << std::endl;
+//   cout << "Gtype is a GtkWidget?:" << GTK_IS_WIDGET(gobj()) << endl;
 
 Level_meter_widget::Level_meter_widget(int channels,
                                        int rate,
